@@ -1,5 +1,6 @@
-trio <-
+trio.prepare <-
 function(trio.dat, freq=NULL, blocks=NULL, logic=TRUE, ...){
+   require(haplo.stats) || stop("Package haplo.stats is required.")
    ifD = FALSE
 
    alleleCode = 1:2
